@@ -50,19 +50,21 @@ Application::Application(int & argc, char ** argv) :
 }
 
 Application::~Application() {
-    // no need to delete m_pMainWindow (DeleteOnClose)
-    // delete m_pMainWindow;
+    qDebug() << "delete MainWindow";
+    delete m_pMainWindow; m_pMainWindow = NULL;
 }
 
 int Application::execute() {
 
     if ( !registerService() ) {
         qWarning() << "There is one instance running already.";
+        /*
         QUrl url(arguments().last());
         if ( url.isValid() ) {
             qDebug() << ">> url on command line: send dbus signal to 'main instance'";
             // ...
         }
+        */
         qWarning() << ">> exiting this instance";
         return 0;
     }
@@ -92,11 +94,15 @@ int Application::execute() {
     m_pMainWindow = newWindow();
     m_pMainWindow->show();
 
-    if ( !m_url.isEmpty() ) {
-        qDebug() << "Event was processed before main window?";
-        visitUrl(m_url, m_fakeUserAgent);
-        m_url = QString::null;
+    /*
+    QUrl url(arguments().last());
+    if ( url.isValid() ) {
+        qDebug() << ">> url on command line: start new window";
+        MainWindow *pWindow = newWindow();
+        pWindow->visitUrl(arguments().last());
+        pWindow->raise();
     }
+    */
 
     return exec();
 }
@@ -104,13 +110,13 @@ int Application::execute() {
 MainWindow* Application::newWindow() {
 
 #ifdef Q_WS_MAEMO_5
-    GraphicsViewWindow *pMainWindow = new GraphicsViewWindow(m_pMainWindow);
-    // WebViewWindow window(NULL);
+    // GraphicsViewWindow *pMainWindow = new GraphicsViewWindow(m_pMainWindow);
+    WebViewWindow *pMainWindow = new WebViewWindow(m_pMainWindow);
 #else
     WebViewWindow *pMainWindow = new WebViewWindow(m_pMainWindow);
 #endif
 
-    pMainWindow->setAttribute(Qt::WA_DeleteOnClose);
+    if ( m_pMainWindow ) pMainWindow->setAttribute(Qt::WA_DeleteOnClose);
 
     return pMainWindow;
 }
@@ -134,15 +140,6 @@ bool Application::registerService() {
 
 void Application::open(const QString &url, bool fakeAgent) {
     qDebug() << "DBus signal:open " << url << ", " << fakeAgent;
-
-    if ( !m_pMainWindow ) {
-        qDebug() << ">> main window hasn't be created yet?";
-        // first time
-        m_url = url;
-        m_fakeUserAgent = fakeAgent;
-        return;
-    }
-
     visitUrl(url, fakeAgent);
 }
 
@@ -150,10 +147,10 @@ void Application::visitUrl(QString url, bool fakeAgent) {
     Q_ASSERT(m_pMainWindow);
 
     // create new window
-    qDebug() << ">> create new window";
+    qDebug() << ">> create new window: " << url;
     MainWindow *pWindow = newWindow();
+    pWindow->showFullScreen();
     pWindow->setUserAgent(fakeAgent);
     pWindow->visitUrl(url);
     pWindow->raise();
-
 }
