@@ -23,8 +23,6 @@ private:
 
 private:
     MainWindow  *m_pMainWindow;
-    QString      m_url;
-    bool         m_fakeUserAgent;
 
 signals:
 
