@@ -48,8 +48,10 @@ void GraphicsView::resizeEvent(QResizeEvent *e) {
 
     QRectF rect(QPointF(0, 0), size());
 
+    qDebug() << "QGraphicsView::resizeEvent " << rect;
+
     setUpdatesEnabled(false);
-    // scene()->setSceneRect(rect);
+    // scene()->setSceneRect(rect); // ????
     viewport->setGeometry(rect);
     setUpdatesEnabled(true);
 
