@@ -20,21 +20,10 @@
 #include <QtGui>
 #include <QDebug>
 
-#include "webviewwindow.h"
-#include "graphicsviewwindow.h"
+#include "application.h"
 
 int main(int argc, char *argv[])
 {
-    QApplication app(argc, argv);
-
-#ifdef Q_WS_MAEMO_5
-    // GraphicsViewWindow window(NULL);
-    WebViewWindow window(NULL);
-#else
-    WebViewWindow window(NULL);
-#endif
-
-    window.show();  
-
-    return app.exec();
+    Application app(argc, argv);
+    return app.execute();
 }
